@@ -27,6 +27,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #define BitsPerCode 3L
 #define MY_METHOD ThreeBit
 
+#include <stdio.h>
+#include <inttypes.h>
+#ifdef DO_PARALLEL
+#include <omp.h>
+#endif
+
+#include <Basic_utils.h>
+#include "intrinsics.h"
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "Bit23.intern.h"
 #include "haplogeno.h"
 #include "Haplo.h"
