@@ -25,10 +25,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #define BitsPerCode 2L
 
-
+#include <inttypes.h>
 #include "IntrinsicsBase.h"
+#include <Basic_utils.h>
 #include "intrinsics.h"
 #include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "dummy.h"
 #include "xport_import.h"
 #include "haplogeno.h"
