@@ -22,12 +22,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
-#include <R.h>
+#include <inttypes.h>
+#include <Basic_utils.h>
+#include <General_utils.h>
+#include <zzz_RandomFieldsUtils.h>
 #include "miraculix.h"
 #include "MX.h"
-#include <Basic_utils.h>
 #include "error.h"
-#include <zzz_RandomFieldsUtils.h>
 #include "dummy.h"
 
 
